#version 120

uniform sampler2D DiffuseSampler;

varying vec2 texCoord;
varying vec2 oneTexel;

uniform vec2 InSize;

uniform vec3 Gray = vec3(0.3, 0.59, 0.11);
uniform vec3 RedMatrix   = vec3(1.0, 0.0, 0.0);
uniform vec3 GreenMatrix = vec3(0.0, 1.0, 0.0);
uniform vec3 BlueMatrix  = vec3(0.0, 0.0, 1.0);
uniform vec3 Offset = vec3(0.0, 0.0, 0.0);
uniform vec3 ColorScale = vec3(1.0, 1.0, 1.0);
uniform float Saturation = 1.8;

uniform float Time;

float dRate() {
    float DRate = 1 / Time;
    return DRate;
}

void main() {
    vec4 InTexel = texture2D(DiffuseSampler, texCoord);
    
    // Color Matrix
    float RedValue = 1 - dot(InTexel.rgb, RedMatrix);
    float GreenValue = 1 - dot(InTexel.rgb, GreenMatrix);
    float BlueValue = 1 - dot(InTexel.rgb, BlueMatrix);

    float Avg = (RedValue + GreenValue + BlueValue) / 3;
    float DRate = dRate();
    float DRed = (RedValue - Avg) * DRate;
    float DGreen = (GreenValue - Avg) * DRate;
    float DBlue = (BlueValue - Avg) * DRate;

    vec3 OutColor = vec3(RedValue - DRed, GreenValue - DGreen, BlueValue - DBlue);

    
    gl_FragColor = vec4(OutColor, InTexel.a);
}